********************************************************************************
* Programa de cálculo de ajuste a cuentas nacionales 2018
* Ultima actualización: 31/01/2024
********************************************************************************

*Las bases de datos de la ENIGH 2018 se pueden descargar en la página de internet del INEGI
*https://www.inegi.org.mx/programas/enigh/nc/2018/#Microdatos.

********************************************************************************
********************************************************************************
******************************PRIMERA PARTE*************************************
********************************************************************************
********************************************************************************

********************************************************************************
* Contenido del programa:
********************************************************************************

* 0. Directorios de trabajo
* 1. Fuentes de ingresos
* 2. Ajuste a cuentas nacionales 
********************************************************************************

clear all
set more off

********************************************************************************
* Módulo 0. Directorios de trabajo
********************************************************************************

* Directorio de carpetas

gl ruta=      "D:\EVALUA\2018"
gl bases=     "$ruta/bases"
gl tmp=       "$ruta/tmp"
gl final=     "$ruta/final"
gl ajusteCN=  "$ruta/ajusteCN"

********************************************************************************
* Módulo 1. Fuentes de ingresos 
*
* 1.1 Factor de expansión y tamaño de hogar
* 1.2 Construcción del ingreso mensual deflactado por claves
* 1.3 Construcción de fuentes de ingresos monetarios 
*   1.3.1 Ingresos por trabajo subordinado
*   1.3.2 Renta de la propiedad
*   1.3.3 Ingresos por negocios propios 
*   1.3.4 Transferencias
* 1.4 Construcción de fuentes de ingresos monetario y no monetarios 
*   1.4.1 Gastos monetario y no monetarios mensual base de hogar
*   1.4.2 Gasto monetario y no monetario mensual base de personas
* 1.5 Construcción del ingreso por negocios según tamaño de empresa
*   *1.5.1 Tamaño de empresa 1
*   *1.5.2 Tamaño de empresa 2
* 1.6 Construcción del ingreso monetario y no monetario deflactado
* 1.7 Construcción de la base Ajustada a Cuentas Nacionales 
********************************************************************************

********************************************************************************
*1.1 Factor de expansión y tamaño de hogar
********************************************************************************

* Abrir base de concentrado hgoar
use "$bases/concentradohogar.dta", clear

* Generar folio único
egen folio=concat(folioviv folioh)

*Generar etiquetas para la variable Tamaño de localidad (tam_loc)
label define tam 1 "100 mil habitantes y mas" ///
                 2 "De 15,000 a 99,999 hab"   ///
				 3 "De 2,500 a 14,999 hab"    ///
				 4 "Menos de 2,500 hab"
destring tam_loc, replace 
label values tam_loc tam

*Se seleccionan las variables de interés
keep folio folioviv foliohog  factor upm tam_loc est_dis

save "$final/factexp.dta", replace

*Abrir base de población
use "$bases/poblacion.dta", clear
egen folio=concat(folioviv folioh)

*Eliminar parentescos que no pertenecen al núcleo familiar
destring parentesco, replace
drop if parentesco>=400 & parentesco <500
drop if parentesco>=700 & parentesco <999

*tamaño de hogar
gen tam_hog=1
collapse (sum) tam_hog, by(folioviv foliohog folio)
save "$tmp/tamano_hogar.dta", replace

*Abrir la base con variables seleccionadas
use "$final/factexp.dta", clear
merge 1:1 folioviv foliohog folio using "$tmp/tamano_hogar.dta"
tab _merge
drop _merge

* base de variables de vivienda y tamaño de hogar 
save "$tmp/factexp.dta", replace

********************************************************************************
* 1.2 Construccion del ingreso mensual deflactado por claves
*********************************************************************************

use "$bases/ingresos.dta", clear 

*Generar variable de decena de levantamiento
gen decena= substr(folioviv,-3,1)
destring decena, replace
recode decena (0/1 = 8 "Agosto") ///
	          (2/4 = 9 "Septiembre") ///
			  (5/7 = 10 "Octubre") ///
			  (8/9 = 11 "Noviembre"), /// 
			  gen (meslevan) label (meslevan)

destring mes_*, replace
	
*Generar folio	
egen folio=concat (folioviv foliohog)

*Generar una variable de ingreso idéntica para hacer modificaciones
gen ing_11=ing_1
gen ing_21=ing_2
gen ing_31=ing_3
gen ing_41=ing_4
gen ing_51=ing_5
gen ing_61=ing_6


*Se regresa a un mes antes para deflactar conforme el mes de referencia
rename ing_11 ing_ma
rename ing_21 ing_11
rename ing_31 ing_21
rename ing_41 ing_31
rename ing_51 ing_41
rename ing_61 ing_51


*Deflactor del INPC tomado de INEGI 2018
scalar par_1 =	0.986858401 // 
scalar par_2 =	0.990050521 // 
scalar par_3 =	0.986693936 // 
scalar par_4 =	0.985094139 // 
scalar par_5 =	0.988899265 // 
scalar par_6 =	0.994199529 // 
scalar par_7 =	1.000000000 // 
scalar par_8 =	1.004229192 // 
scalar par_9 =	1.009433587 // 

*Deflactor 5-> den 5
gen den5=.
replace den5= par_1 if meslevan==8
replace den5= par_2 if meslevan==9
replace den5= par_3 if meslevan==10
replace den5= par_4 if meslevan==11

*Deflactor 4-> den 4
gen den4=.
replace den4= par_2 if meslevan==8
replace den4= par_3 if meslevan==9
replace den4= par_4 if meslevan==10
replace den4= par_5 if meslevan==11

*Deflactor 3-> den 3
gen den3=.
replace den3= par_3 if meslevan==8
replace den3= par_4 if meslevan==9
replace den3= par_5 if meslevan==10
replace den3= par_6 if meslevan==11

*Deflactor 2-> den 2
gen den2=.
replace den2= par_4 if meslevan==8
replace den2= par_5 if meslevan==9
replace den2= par_6 if meslevan==10
replace den2= par_7 if meslevan==11

*Deflactor 1-> den 1
gen den1=.
replace den1= par_5 if meslevan==8
replace den1= par_6 if meslevan==9
replace den1= par_7 if meslevan==10
replace den1= par_8 if meslevan==11

*Deflactor principal -> den ma
gen denma=.
replace denma= par_6 if meslevan==8
replace denma= par_7 if meslevan==9
replace denma= par_8 if meslevan==10
replace denma= par_9 if meslevan==11

*Se deflactan de acuerdo al mes de levantamiento
replace ing_51=ing_6/den5 
replace ing_41=ing_5/den4 
replace ing_31=ing_4/den3 
replace ing_21=ing_3/den2 
replace ing_11=ing_2/den1 
replace ing_ma=ing_1/denma 

*Para poder hacer el loop se genera el valor numérico de la clave
gen clave_sin= substr(clave,-2,2)
destring clave_sin, replace

*recodificar para poder sumar todos los ingresos 
recode ing_51 ing_41  ing_31  ing_21  ing_11  ing_ma (.=0)

* Loop para generar la suma del ingreso deflactado para cada clave de ingreso
forvalues i= 1 / 108 {
 gen P_`i'=0
 replace P_`i' = ing_51 + ing_41 + ing_31 + ing_21 + ing_11 + ing_ma if clave_sin==`i'
 replace P_`i'= 0 if P_`i'==.
}

* Loop para generar ingreso mensual
foreach i of numlist 1/7 10/14 17/49 51/81 {
 gen P_M`i'=0
 replace P_M`i'= P_`i'/6
}
*
foreach i of numlist 8/9 15/16 50{
 gen P_M`i'=0
 replace P_M`i'= P_`i'/12
}

recode P_M1-P_M50(.=0)

* Seleccionar variables
keep folioviv foliohog numren folio P_M1-P_M50

* Guarda base de datos
collapse (sum) P_M1-P_M50, by(folio numren)
save "$ajusteCN/ingresos_agregadoxp.dta", replace 

********************************************************************************
* 1.3 Construcción de fuentes de ingresos monetarios 
*********************************************************************************

********************************************************************************
* 1.3.1 Ingresos por trabajo subordinado
********************************************************************************

use "$ajusteCN/ingresos_agregadoxp.dta", clear 

* Sueldos
gen double sueldos    = P_M1+P_M2+P_M11+P_M14+P_M18+P_M67
* Horas extras
gen double horas      = P_M4
* Comisiones y propinas
gen double double comisiones =P_M3
* Aguinaldo y reparto de utilidades
gen double aguinaldo  = P_M8+P_M9+P_M15+P_M16
*Indemnizaciones
gen double indemni    = P_M35+P_M36 
* Otras remuneraciones monetarias
gen double monetarias = P_M5+P_M6+P_M7+P_M21+P_M22
* Otras ingresos
gen double otros_ing  = P_M49
recode sueldos-otros_ing (.=0)

*Ingresos por trabajo subordinado
gen double remuneraciones= sueldos+horas+comisiones+aguinaldo+indemni+monetarias+otros_ing

********************************************************************************
* 1.3.2 Renta de la propiedad
********************************************************************************

* Arrendamiento de activos tangibles y financieros
gen double interes     = P_M26+P_M27+P_M28
gen double alquiler    = P_M30
gen double otras_ren   = P_M31
gen double dividendos  = P_M29+P_M50
gen double alq_inm     = P_M24+P_M25
gen double alq_tierras = P_M23
recode interes-alq_tierras (.=0)

* Renta de la propiedad
gen double renta_prop  = interes+alquiler+otras_ren+dividendos+alq_inm+alq_tierras 

********************************************************************************
* 1.3.3 Ingresos por negocios propios 
********************************************************************************
*ingreso por cooperativas 
gen double YCOOP        =P_M12+P_M19+P_M13+P_M20
*Ingresos de negocios agropecuarios
gen double YAGRO_sincoop=P_M71+P_M72+P_M73+P_M74+P_M78+P_M79+P_M80+P_M81
*Ingresos de negocios NO agropecuarios 
gen double YNOAGRO_sincoop=P_M68+P_M69+P_M70+P_M75+P_M76+P_M77
recode YCOOP YAGRO_sincoop YNOAGRO_sincoop (.=0)

********************************************************************************
* 1.3.4 Transferencias
********************************************************************************

* Jubilaciones y pensiones
gen double jubilaciones =P_M32+P_M33
* Indemnizaciones
gen double indemnizaciones= P_M34
* Becas de instituciones privadas o de organismos no gubernamentales 
gen double becas       =P_M37
* Ingresos provenientes de otros países
gen double remesas     =P_M41
* Transferencias no gubernamentales
gen double trans_nogob=P_M32+P_M33+P_M37+P_M41+P_M34
* Beneficios de programas gubernamentales
gen double trans_gob   =P_M42+P_M43+P_M44+P_M45+P_M46+P_M47+P_M48+P_M38
recode jubilaciones-trans_gob (.=0)
recode sueldos-trans_gob(.=0)
recode P_M39 P_M40 (.=0)

* Generar ingreso por fuentes mensualizado individual 
collapse (sum) P_M34 P_M9 P_M16 P_M35 P_M36 P_M38 P_M39 P_M40 sueldos-trans_gob, by(folio numren)
save "$ajusteCN/Ing_PC_2018.dta", replace

* Generar ingreso por fuentes mensualizado por hogar 
collapse (sum) P_M34 P_M9 P_M16 P_M35 P_M36 P_M39 P_M40 sueldos-trans_gob, by(folio)

save "$ajusteCN/Ingxfuentes_hogar.dta", replace

********************************************************************************
* 1.4 Construcción de fuentes de ingresos monetario y no monetarios 
*********************************************************************************

********************************************************************************
* 1.4.1 Gastos monetario y no monetarios mensual base de hogares

*  Monetario:
*  G2 Gasto monetario en bienes y servicios para otro hogar 

*  No Monetario:
*  G3 Gasto no monetario procedente de autoconsumo 
*  G5 Gasto no monetario por regalos recibidos de otro hogar 
*  G6 Gasto no monetario por transferencias de instituciones 
*  G7 Gasto imputado por estimación del alquiler
********************************************************************************

* Abrir la base de Gastos por hogar
use "$bases/gastoshogar.dta",clear 

* Generar folio único
egen folio=concat (folioviv foliohog)

* Variable de frecuencia
gen frec_unavez=0
replace frec_unavez=1 if frecuencia=="5" & tipo_gasto=="G5"

* Variable de claves a excluir
gen excep=0
replace excep=1 if clave>="Q001" & clave<="Q016"  | clave>="K038" & clave<="K045"

*Generar decena de levantamiento
gen decena= substr(folio,8,1)
destring decena, replace
recode decena (0/1 = 8 “Agosto”) /// 
              (2/4 = 9 “Septiembre”) /// 
			  (5/7 = 10 “Octubre”) /// 
			  (8/9 = 11 “Noviembre”), /// 
			  gen (meslevan) label (meslevan)

gen  double g2_gas_m_tri=gasto_tri   if ((clave>="T901" & clave<="T906")  | (clave>= "T908" & clave<="T915"))   & tipo_gasto=="G2"
gen  double g3_gas_nm_tri=gas_nm_tri if tipo_gasto=="G3" & excep==0
gen  double g5_gas_nm_tri=gas_nm_tri if (tipo_gasto=="G5" & excep==0)
gen  double g6_gas_nm_tri=gas_nm_tri if (tipo_gasto=="G6" & excep==0)
gen  double g7_gas_nm_tri=gas_nm_tri if tipo_gasto=="G7"
gen  double N013_tri=gasto_tri       if (clave=="N013" & tipo_gasto=="G1")
recode   g2_gas_m_tri-N013_tri  (.=0)


* Deflactor del INPC tomado de INEGI 2018
gen deflac=0
replace deflac = 1.000000000 if meslevan==8
replace deflac = 1.004229192 if meslevan==9
replace deflac = 1.009433587 if meslevan==10
replace deflac = 1.018021335 if meslevan==11

gen double g2_def= (((g2_gas_m_tri)   / deflac)/3)
gen double g3_def = (((g3_gas_nm_tri) / deflac)/3)
gen double g5_def = (((g5_gas_nm_tri) / deflac)/3)
gen double g6_def = (((g6_gas_nm_tri) / deflac)/3)
gen double g7_def = (((g7_gas_nm_tri) / deflac)/3)
gen double N013_def= (((N013_tri) / deflac)/3)

* Collapsar a nivel de hgoar
collapse (sum) g2_def-N013_def, by(folio)

* Guardamos la base 
save "$ajusteCN/gastohogar_no_mon_h.dta", replace 

********************************************************************************
* 1.4.2 Gasto monetario y no monetario mensual base de personas

*  G1 Gasto monetario en bienes y servicios para el hogar 
*  G4. Gasto no monetario por remuneraciones en especie 
********************************************************************************

* Abrir base de gastos por persona
use "$bases/gastospersona.dta",clear 

* Generar folio
egen folio=concat (folioviv foliohog)

* Variable de claves a excluir
gen excep=0
replace excep=1 if clave>="Q001" & clave<="Q016"  | clave>="K038" & clave<="K045"

* Generar decena de levantamiento
gen decena= substr(folio,8,1)
destring decena, replace
recode decena ///
	(0/1 = 8 “Agosto”) ///
	(2/4 = 9 “Septiembre”) ///
	(5/7 = 10 “Octubre”) ///
	(8/9 = 11 “Noviembre”), ///
	gen (meslevan) label (meslevan)
	
* Generar variables para cada tipo de gasto
gen double g1_gas_m_tri=0
replace g1_gas_m_tri=gasto_tri if (tipo_gasto=="G1")

gen double g4_gas_m_tri=gas_nm_tri if tipo_gasto=="G4" & excep==0
recode g1_gas_m_tri g4_gas_m_tri(.=0)

* Deflactor del INPC tomado de INEGI 2018 
gen deflac=0
replace deflac = 1.000000000 if meslevan==8
replace deflac = 1.004229192 if meslevan==9
replace deflac = 1.009433587 if meslevan==10
replace deflac = 1.018021335 if meslevan==11

* Gasto G1 y G4 deflactado
gen double g1_def = (((g1_gas_m_tri) / deflac)/3)
gen double g4_def = (((g4_gas_m_tri) / deflac)/3)
recode g1_def g4_def (.=0)

* Guardar base a nivel persona
save "$ajusteCN/gastospersona_no_mon_i.dta", replace 

* Guardar base a nivel hogar
collapse (sum) g4_def g4_gas_m_tri, by (folio )
save "$ajusteCN/gastospersona_no_mon_h.dta", replace 


********************************************************************************
* 1.5 Construcción del ingreso por negocios según tamaño de empresa 
********************************************************************************

********************************************************************************
* 1.5.1 Tamaño de empresa 1
********************************************************************************

* Identificador del tamaño de empresa
use "$bases/trabajos.dta", clear 
egen folio=concat (folioviv foliohog)

keep if id_trabajo == "1" & subor == "2"

destring tam_emp id_trabajo, replace
collapse  (max) tam_emp id_trabajo, by(folio numren)

rename tam_emp  tam_emp_1
rename id_trabajo id_trabajo_1

* Guardar base
save "$ajusteCN/Neg_1ertrab.dta", replace

********************************************************************************
* 1.5.2 Tamaño de empresa 2
********************************************************************************

* Abrir base
use "$bases/trabajos.dta", clear 
egen folio=concat (folioviv foliohog)

keep if id_trabajo == "2" & subor == "2"
destring tam_emp id_trabajo, replace

collapse  (max) tam_emp id_trabajo, by(folio numren)

rename tam_emp  tam_emp_2
rename id_trabajo id_trabajo_2

* Guardar base
save "$ajusteCN/Neg_2otrab.dta", replace

********************************************************************************
* 1.5.3 Origen del ingreso por tipo de negocio (agropecuario y no agropecuario)
********************************************************************************
* Abrir base
use "$ajusteCN/Ing_PC_2018.dta", clear

merge 1:1 folio numren using "$ajusteCN/Neg_1ertrab.dta"
drop if _merge==2
drop _merge

merge 1:1 folio numren using "$ajusteCN/Neg_2otrab.dta"
drop if _merge==2
drop _merge 


recode sueldos-trans_gob (.=0)

gen id_tipos_Y_coop=0
replace id_tipos_Y_coop=1 if YCOOP>0 & YAGRO_sincoop==0 & YNOAGRO_sincoop==0
replace id_tipos_Y_coop=2 if YCOOP>0 & YAGRO_sincoop>0 & YNOAGRO_sincoop==0
replace id_tipos_Y_coop=3 if YCOOP>0 & YAGRO_sincoop==0 & YNOAGRO_sincoop>0
replace id_tipos_Y_coop=4 if YCOOP>0 & YAGRO_sincoop==1 & YNOAGRO_sincoop==1

label define id_tipos_Y_coop 1 "sólo coop" ///
                             2 "Coop + Agro" ///
							 3 "Coop + No Agro" ///
							 4 "Coop con ambos" 
label values id_tipos_Y_coop id_tipos_Y_coop

merge m:1 folio using "$final/factexp.dta"

drop if _merge==2
drop _merge 

* Generar el ingreso agropecuario con y sin cooperativas 
gen double Y_AGRO_con_coop=YAGRO_sincoop
replace Y_AGRO_con_coop=YAGRO_sincoop  + YCOOP if YAGRO_sincoop>0 & YNOAGRO_sincoop==0
replace Y_AGRO_con_coop=YCOOP                  if YAGRO_sincoop==0 & YNOAGRO_sincoop==0 & tam_loc==4


* Generar el ingreso NO agropecuario con y sin cooperativas
gen double Y_NO_AGRO_con_coop=YNOAGRO_sincoop
replace Y_NO_AGRO_con_coop=YNOAGRO_sincoop  + YCOOP if YAGRO_sincoop==0 & YNOAGRO_sincoop>0
replace Y_NO_AGRO_con_coop=YNOAGRO_sincoop  + YCOOP if  YAGRO_sincoop==0 & YNOAGRO_sincoop==0 & tam_loc<4
replace Y_NO_AGRO_con_coop = YNOAGRO_sincoop + YCOOP if (YCOOP>0 & YAGRO_sincoop>0 & YNOAGRO_sincoop >0)

recode Y_AGRO_con_coop-Y_NO_AGRO_con_coop(.=0)

* Identificador del tamaño de empresa urbano y rural

destring tam_emp_1, replace
destring tam_emp_2, replace

recode tam_emp_1 tam_emp_2 (.=0)

rename tam_emp_1 tam_empresa1
rename tam_emp_2 tam_empresa2

gen tam_emp =  tam_empresa1
replace tam_emp=tam_empresa2 if tam_empresa1==0

* Tamaño de empresas agropecuarias
gen tam_emp_ajuste=tam_emp
recode tam_emp_ajuste (1 2=1) (0=.)
recode tam_emp_ajuste (9 10 11 12=9) (0=.)

* Tamaño de empresas no agropecuarias
gen tam_emp_ajuste_rural=tam_emp
recode tam_emp_ajuste_rural (1 2=1) (0=.)
recode tam_emp_ajuste_rural (5 6 7 8 9 10 11 12=5) (0=.)


label define tam_emp_ajuste 1 "1 a 5"    ///
                            3 "6 a 10"   /// 
							4 "11 a 15"  /// 
							5 "16 a 20"  /// 
							6 "21 a 30"  /// 
							7 "31 a 50"  /// 
							8 "51 a 100" /// 
							9 "101 a MÁS" 
label values tam_emp_ajuste tam_emp_ajuste


label define tam_emp_ajuste_rural 1 "1 a 5"   /// 
                                  3 "6 a 10"  /// 
								  4 "11 a 15" /// 
								  5 "16 a más"

label values tam_emp_ajuste_rural tam_emp_ajuste_rural
recode tam_emp_ajuste tam_emp_ajuste_rural (.=0)

tabstat Y_NO_AGRO_con_coop, statistics(sum mean N) format(%22.2fc)
tabstat Y_AGRO_con_coop, statistics(sum mean N)  format(%22.2fc)

* Ingreso Agro y No Agro con cooperativa
tabstat Y_AGRO_con_coop Y_NO_AGRO_con_coop  [fw=factor], format(%22.2fc) statistics(sum N)

* Guardar base a nivel de persoans
save "$ajusteCN/ingresos_negocios_p.dta", replace

* Guardar base a nivel de hogares
collapse (sum) Y_AGRO_con_coop Y_NO_AGRO_con_coop, by(folio)
save "$ajusteCN/ingresos_negocios_h.dta", replace


********************************************************************************
* 1.6 Construcción del ingreso monetario y no monetario deflactado
*******************************************************************************

* Abrir base
use "$final/factexp.dta",clear 

* Pegar las bases de gasto no monetario creadas
merge 1:1 folio using "$ajusteCN/Ingxfuentes_hogar.dta"
drop _merge
merge 1:1 folio using "$ajusteCN/gastospersona_no_mon_h.dta"
drop _merge
merge 1:1 folio using "$ajusteCN/gastohogar_no_mon_h.dta"
drop _merge
merge 1:1 folio using "$ajusteCN/ingresos_negocios_h.dta"
drop _merge
recode P_M34-Y_NO_AGRO_con_coop (.=0)

* Borrar gasto no monetario procedente de autoconsumo
drop g3_def 

*******************************************************************************
* 1.7 Fuentes de ingresos para empatar a cuentas nacionales 
*******************************************************************************

* Formato a variables
format %20.2fc P_M34-Y_NO_AGRO_con_coop 

* Ingresos por trabajo subordinado
gen double remu_asala= remuneraciones+ g4_def
* Estimación del alquiler
gen double impu_vivi =g7_def
* Ingresos por trabajo independiente
gen double rent_empre=Y_AGRO_con_coop+Y_NO_AGRO_con_coop
* Renta de la propiedad
gen double rent_prop =interes+alquiler+otras_ren+dividendos+alq_inm+alq_tierras
* Regalos netos (Sin valores negativos)
gen double reg_netos=(P_M40+g5_def)-(g2_def+N013_def)
replace reg_netos = 0 if reg_netos <= 0
* Transferencias institucionales (donativos+transferencias de instituciones) 
gen double tran_inst=P_M39+g6_def
* tranferencias
gen double trans_t=trans_nogob+reg_netos+tran_inst+trans_gob  
* Ingreso total
gen double IC_total=remu_asala+impu_vivi+rent_empre+rent_prop+trans_t 


*Resultados de ingresos monetario y no monetario para empatarlas a cuentas nacionales
tabstat remu_asala impu_vivi rent_empre rent_prop trans_t trans_gob IC_total  [fw=factor], format(%22.3fc) statistics(sum) columns(statistics)

*************************
* INGRESOS DESAGREGADOS *
*************************

* Remuneraciones
tabstat sueldos horas comisiones aguinaldo indemni monetarias g4_def otros_ing [fw=factor], format(%22.3fc) statistics(sum) columns(statistics)

* Renta imputada de la vivienda
tabstat impu_vivi [fw=factor], format(%22.3fc) statistics(sum) columns(statistics)

* Renta de la propiedad
tabstat interes alquiler otras_ren dividendos alq_inm  alq_tierras[fw=factor], format(%22.3fc) statistics(sum) columns(statistics)

* Ingresos por negocios propios
tabstat  YCOOP  YAGRO_sincoop YNOAGRO_sincoop [fw=factor], format(%22.3fc) statistics(sum) columns(statistics)

* Ingresos por negocios propios )
tabstat jubilaciones becas remesas indemnizaciones trans_gob tran_inst reg_netos [fw=factor], format(%22.3fc) statistics(sum) columns(statistics)

* Guardar base
save "$ajusteCN/ingresos_fuentes.dta", replace

* Resultados de ingresos de negocios según tamaño de empresa para empatarlas a cuentas nacionales
use  "$ajusteCN/ingresos_negocios_p.dta", clear
tabstat Y_NO_AGRO_con_coop  if Y_NO_AGRO_con_coop>0 [fw=factor], by (tam_emp_ajuste) format(%22.2fc) statistics(sum) 
tabstat Y_AGRO_con_coop     if Y_AGRO_con_coop >0 [fw=factor], by (tam_emp_ajuste_rural) format(%22.2fc) statistics(sum) 

********************************************************************************
* Módulo 2. Ajuste a cuentas nacionales
* 2.1 Construcción del ingreso por negocios ajustado a cuentas nacionales
* 2.2 Construcción del ingreso por remuneraciones en especies ajustado a cuentas nacionales
* 2.3 Construcción del ingreso por regalos y transferencias institucionales a cuentas nacionales
* 2.4 Construcción del ingreso estimación del alquiler ajustado a cuentas nacionales
* 2.5 Construcción de las fuentes de ingreso monetario ajustado a cuentas nacionales
* 2.6 Construcción del ingreso monetario y no monetario ajustado a cuentas nacionales 
********************************************************************************

********************************************************************************
* 2.1 Construcción del ingreso por negocios ajustado a cuentas nacionales
********************************************************************************

* Abrir base
use  "$ajusteCN/ingresos_negocios_p.dta", clear

scalar tam1=	1.00000000
scalar tam3=	3.17153804
scalar tam4=	6.03353861
scalar tam5=	8.94512353
scalar tam6=	8.38349161
scalar tam7=	6.31769762
scalar tam8=	33.91025056
scalar tam9=	370.10923787

* Factores de ajuste para el sector No Agropecuario
gen double YNagro_ACN=0

replace YNagro_ACN=Y_NO_AGRO_con_coop*tam1 if tam_emp_ajuste==1
replace YNagro_ACN=Y_NO_AGRO_con_coop*tam3 if tam_emp_ajuste==3
replace YNagro_ACN=Y_NO_AGRO_con_coop*tam4 if tam_emp_ajuste==4
replace YNagro_ACN=Y_NO_AGRO_con_coop*tam5 if tam_emp_ajuste==5
replace YNagro_ACN=Y_NO_AGRO_con_coop*tam6 if tam_emp_ajuste==6
replace YNagro_ACN=Y_NO_AGRO_con_coop*tam7 if tam_emp_ajuste==7
replace YNagro_ACN=Y_NO_AGRO_con_coop*tam8 if tam_emp_ajuste==8
replace YNagro_ACN=Y_NO_AGRO_con_coop*tam9 if tam_emp_ajuste==9 

scalar tam1r=	1.00000000
scalar tam3r=	1.00000000
scalar tam4r=	1.12017421
scalar tam5r=	8.19307056

* Factores de ajuste para el sector Agropecuario
gen double Yagro_ACN=0

replace Yagro_ACN= Y_AGRO_con_coop*tam1r   if tam_emp_ajuste_rural==1
replace Yagro_ACN=Y_AGRO_con_coop*tam3r   if tam_emp_ajuste_rural==3
replace Yagro_ACN=Y_AGRO_con_coop*tam4r   if tam_emp_ajuste_rural==4
replace Yagro_ACN=Y_AGRO_con_coop*tam5r   if tam_emp_ajuste_rural==5
recode YNagro_ACN Yagro_ACN (.=0)

* Tablas
tabstat YNagro_ACN [fw=factor], statistics(sum) format(%22.2fc)
tabstat Yagro_ACN  [fw=factor], statistics(sum) format(%22.2fc)

* Guardar base
collapse (sum) YNagro_ACN Yagro_ACN  Y_NO_AGRO_con_coop Y_AGRO_con_coop, by(folio)
save "$ajusteCN/Ing_neg_ACN.dta", replace 

*******************************************************************************
* 2.2 Construcción del ingreso por remuneraciones en especies ajustado a cuentas nacionales
********************************************************************************

* Abrir base
use "$ajusteCN/gastospersona_no_mon_i.dta", clear

*Gasto no monetario por remuneraciones en especie ajustado a cuentas nacionales
gen double g4_def_ACN= 1.012706337 * g4_def 

* Guardar base
collapse (sum) g4_def_ACN  , by(folio)
save "$ajusteCN/Ing_rem_especie_ACN.dta", replace 

*******************************************************************************
* 2.2 Construcción del ingresos por regalos y transferencias institucionales a cuentas nacionales
*******************************************************************************

use "$ajusteCN/ingresos_fuentes.dta", clear

scalar fa_trans= 2.337076353

gen double reg_netos_ACN=reg_netos *fa_trans
gen double trans_int_ACN= tran_inst *fa_trans

* Guardar base
keep folio reg_netos_ACN trans_int_ACN 
save "$ajusteCN/tran_no_mono.dta", replace 

*******************************************************************************
* 2.4 Construcción del ingreso estimación del alquiler ajustado a cuentas nacionales
*******************************************************************************

* Abrir base
use "$ajusteCN/gastohogar_no_mon_h.dta", clear

* Estimación del alquiler ajustado
gen double g7_def_ACN= 1.342098219 * g7_def 
keep folio g7_def_ACN

collapse (sum) g7_def_ACN, by(folio)

save "$ajusteCN/alquiler_ACN.dta", replace 

******************************************************************************
* 2.5 Construcción de las fuentes de ingreso monetario ajustado a cuentas nacionales 
*******************************************************************************

* Abrir base
use "$final/factexp.dta",clear 

scalar	fa_remun=	1.012706337
scalar	fa_renta=	41.565334511
scalar	fa_trans=	2.337076353
merge 1:1 folio using "$ajusteCN/Ingxfuentes_hogar.dta"
drop _merge

recode remun-YNOAGRO_sincoop (.=0)

* Ingreso ajustado por ajuste a cuentas nacionales

gen double remun_ACN    =remun*fa_remun
gen double renta_ACN    =renta_prop*fa_renta
 
gen double tran_gobACN  = trans_gob*1.000000
gen double tran_nogobACN= trans_nogob*fa_trans


gen double p034_ACN     =P_M34*fa_trans
gen double p035_ACN     =P_M35*fa_remun
gen double p036_ACN     =P_M36*fa_remun
gen double p009_ACN     =P_M9* fa_remun
gen double p016_ACN     =P_M16*fa_remun
recode remun_ACN-p016_ACN (.=0)

* Guardar base
collapse (sum) remun_ACN renta_ACN tran_gobACN tran_nogobACN p034_ACN p035_ACN p036_ACN p009_ACN p016_ACN, by(folio)
save "$ajusteCN/Ingxfuentes_ACN.dta", replace 
 
********************************************************************************
* 2.6 Construcción del ingreso monetario y no monetario ajustado a cuentas nacionales
********************************************************************************

* Abrir base
use "$final/factexp.dta",clear 

merge 1:1 folio using "$ajusteCN/Ing_rem_especie_ACN.dta"
drop _merge
merge 1:1 folio using "$ajusteCN/alquiler_ACN.dta"
drop _merge
merge 1:1 folio using "$ajusteCN/Ing_neg_ACN.dta"
drop _merge
merge 1:1 folio using "$ajusteCN/Ingxfuentes_ACN.dta"
drop _merge
merge 1:1 folio using "$ajusteCN/tran_no_mono.dta"
drop _merge 
recode g4_def_ACN-trans_int_ACN(.=0)

* Comprobación de ajuste a cuentas nacionales
gen double remun=remun_ACN+g4_def_AC
gen double imp_viv=g7_def_ACN
gen double EBO=YNagro_ACN +Yagro_ACN
gen double transf=tran_gobACN+ tran_nogobACN+reg_netos_ACN+trans_int_ACN
gen double renta=renta_ACN
gen double ing_total=remun+imp_viv+EBO+transf+renta
tabstat remun imp_viv EBO renta transf tran_gobACN tran_nogobACN trans_int_ACN reg_netos_ACN ing_total [fw=factor], format(%22.2fc) statistics(sum) columns(statistics)

* Selección de variables
keep folio factor remun imp_viv EBO renta transf tran_gobACN tran_nogobACN p034_ACN p035_ACN p036_ACN p009_ACN p016_ACN

* Nombre de variables finales
rename remun remun_ACN
rename imp_viv imp_viv_ACN
rename EBO EBO_ACN
rename transf transf_ACN
rename renta renta_ACN

* Etiquetas de variables
label var  folio	          "Folio"
label var  remun_ACN	      "Remuneración por trabajo subordinado mensual ajustado"
label var  imp_viv_ACN        "Estimación del Alquiler mensual ajustado"
label var  EBO_ACN            "Ingreso por negocios mensual ajustado"
label var  transf_ACN         "Ingreso por transferencias mensual ajustado"
label var  renta_ACN          "Renta de la propiedad mensual ajustado"
label var  p034_ACN           "Ingreso indemn. por seguros contra riesgos a terceros mensual ajustado"
label var  p035_ACN           "Ingreo indemn. por accidentes de trabajo mensual ajustado"
label var  p036_ACN           "Ingreso indemn. por despido y retiro involuntario mensual ajustado"
label var  p009_ACN           "Aguinaldo del ejercicio 2019 (Trabajo principal)"
label var  p016_ACN           "Aguinaldo del ejercicio 2019 (Trabajo principal)"
label var  tran_gobACN        "Ingresos por transferencias de gobierno ajustado"
label var  tran_nogobACN      "Ingresos por transferencias de no gubernamentales ajustado"

* Guardar base final de ajuste a cuentas nacionales
save  "$bases/base_final_ACN.dta", replace
